==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/ux/ToggleButton.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _superPropGet(t, e, o, r) { var p = _get(_getPrototypeOf(1 & r ? t.prototype : t), e, o); return 2 & r && "function" == typeof p ? function (t) { return p.apply(o, t); } : p; }
function _get() { return _get = "undefined" != typeof Reflect && Reflect.get ? Reflect.get.bind() : function (e, t, r) { var p = _superPropBase(e, t); if (p) { var n = Object.getOwnPropertyDescriptor(p, t); return n.get ? n.get.call(arguments.length < 3 ? e : r) : n.value; } }, _get.apply(null, arguments); }
function _superPropBase(t, o) { for (; !{}.hasOwnProperty.call(t, o) && null !== (t = _getPrototypeOf(t));); return t; }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * @copyright 2020 Tridium, Inc. All Rights Reserved.
 * @author JJ Frankovich
 */

/* jshint browser: true */ /* eslint-env browser */

/**
 * API Status: **Private**
 * @module nmodule/bajaui/rc/ux/ToggleButton
 */
define(['baja!', 'baja!bajaui:Halign', 'bajaux/spandrel', 'jquery', 'nmodule/bajaui/rc/ux/Button'], function (baja, types, spandrel, $, Button) {
  'use strict';

  var widgetDefaults = function widgetDefaults() {
    return {
      properties: {
        rootCssClass: 'ux-Button ux-ToggleButton',
        selected: false
      }
    };
  };

  /**
   * ToggleButton is a Widget for bajaui:ToggleButton.
   *
   * ToggleButton supports an addition web property called `keepSelected=true`.
   * This designates that the ToggleButton will remain selected even if a user attempts to
   * unselect the button. Non-user changes can still unselect the button even if the web property is present.
   *
   * @class
   * @alias module:nmodule/bajaui/rc/ux/ToggleButton
   * @extends module:nmodule/bajaui/rc/ux/Button
   */
  return /*#__PURE__*/function (_spandrel) {
    function ToggleButton(params) {
      _classCallCheck(this, ToggleButton);
      return _callSuper(this, ToggleButton, [{
        params: params,
        defaults: widgetDefaults()
      }]);
    }

    /**
     * @returns {Promise}
     */
    _inherits(ToggleButton, _spandrel);
    return _createClass(ToggleButton, [{
      key: "doInvokeAction",
      value: function doInvokeAction(e) {
        var selected = this.properties().getValue('selected');
        var keepSelected = this.properties().getValue('keepSelected');
        var newSelected = !selected;
        //don't allow any the ToggleButton to transition to selected=false from a user press if WebProperty `keepSelected=true`
        if (selected && keepSelected) {
          return Promise.resolve();
        }
        this.properties().setValue('selected', newSelected);
        return _superPropGet(ToggleButton, "doInvokeAction", this, 3)(arguments);
      }
    }, {
      key: "render",
      value: function render() {
        //TODO: NCCB-45981 - Possibly remove this workaround after we fix this problem for all inputs in spandrel?
        // would also be nice to leave this render override out, but Button.render does NOT get called for ToggleButton
        //when there is a click of the input
        return Button.prototype.render.apply(this, arguments);
      }
    }]);
  }(spandrel(function (value, _ref) {
    var properties = _ref.properties,
      renderSuper = _ref.renderSuper;
    return renderSuper().then(function (result) {
      var selected = properties.selected;
      if (selected) {
        result[0].dom.classList.add('ux-Button-buttonStyle-selected');
      }
      return result;
    });
  }, {
    "extends": Button
  }));
});

==> Tridium_EMEA_N4_Supervisor-4.14.2.12.zip: rc/ux/ToggleButton.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _superPropGet(t, e, o, r) { var p = _get(_getPrototypeOf(1 & r ? t.prototype : t), e, o); return 2 & r && "function" == typeof p ? function (t) { return p.apply(o, t); } : p; }
function _get() { return _get = "undefined" != typeof Reflect && Reflect.get ? Reflect.get.bind() : function (e, t, r) { var p = _superPropBase(e, t); if (p) { var n = Object.getOwnPropertyDescriptor(p, t); return n.get ? n.get.call(arguments.length < 3 ? e : r) : n.value; } }, _get.apply(null, arguments); }
function _superPropBase(t, o) { for (; !{}.hasOwnProperty.call(t, o) && null !== (t = _getPrototypeOf(t));); return t; }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * @copyright 2020 Tridium, Inc. All Rights Reserved.
 * @author JJ Frankovich
 */

/* jshint browser: true */ /* eslint-env browser */

/**
 * API Status: **Private**
 * @module nmodule/bajaui/rc/ux/ToggleButton
 */
define(['baja!', 'baja!bajaui:Halign', 'bajaux/spandrel', 'jquery', 'Promise', 'nmodule/bajaui/rc/ux/Button'], function (baja, types, spandrel, $, Promise, Button) {
  'use strict';

  var widgetDefaults = function widgetDefaults() {
    return {
      properties: {
        rootCssClass: 'ux-Button ux-ToggleButton',
        selected: false
      }
    };
  };

  /**
   * ToggleButton is a Widget for bajaui:ToggleButton.
   *
   * ToggleButton supports an addition web property called `keepSelected=true`.
   * This designates that the ToggleButton will remain selected even if a user attempts to
   * unselect the button. Non-user changes can still unselect the button even if the web property is present.
   *
   * @class
   * @alias module:nmodule/bajaui/rc/ux/ToggleButton
   * @extends module:nmodule/bajaui/rc/ux/Button
   */
  return /*#__PURE__*/function (_spandrel) {
    function ToggleButton(params) {
      _classCallCheck(this, ToggleButton);
      return _callSuper(this, ToggleButton, [{
        params: params,
        defaults: widgetDefaults()
      }]);
    }

    /**
     * @returns {Promise}
     */
    _inherits(ToggleButton, _spandrel);
    return _createClass(ToggleButton, [{
      key: "doInvokeAction",
      value: function doInvokeAction(e) {
        var selected = this.properties().getValue('selected');
        var keepSelected = this.properties().getValue('keepSelected');
        var newSelected = !selected;
        //don't allow any the ToggleButton to transition to selected=false from a user press if WebProperty `keepSelected=true`
        if (selected && keepSelected) {
          return Promise.resolve();
        }
        this.properties().setValue('selected', newSelected);
        return _superPropGet(ToggleButton, "doInvokeAction", this, 3)(arguments);
      }
    }, {
      key: "render",
      value: function render() {
        //TODO: NCCB-45981 - Possibly remove this workaround after we fix this problem for all inputs in spandrel?
        // would also be nice to leave this render override out, but Button.render does NOT get called for ToggleButton
        //when there is a click of the input
        return Button.prototype.render.apply(this, arguments);
      }
    }]);
  }(spandrel(function (value, _ref) {
    var properties = _ref.properties,
      renderSuper = _ref.renderSuper;
    return renderSuper().then(function (result) {
      var selected = properties.selected;
      if (selected) {
        result[0].dom.classList.add('ux-Button-buttonStyle-selected');
      }
      return result;
    });
  }, {
    "extends": Button
  }));
});
